# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('episodeofcare', '0002_initial'),
        ('procedures', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='episodeofcarereasonvaluereference',
            name='procedure',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reason_value_reference_procedure', to='procedures.procedure'),
        ),
        migrations.AddField(
            model_name='episodeofcarereasonvaluecodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reason_value_codeable_reference_reference', to='episodeofcare.episodeofcarereasonvaluereference'),
        ),
        migrations.AddField(
            model_name='episodeofcarereference',
            name='episode_of_care',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reference_episode_of_care', to='episodeofcare.episodeofcare'),
        ),
        migrations.AddField(
            model_name='episodeofcarereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='episodeofcarestatushistory',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_status_history_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='status_history',
            field=models.ManyToManyField(blank=True, related_name='episode_of_care_status_history', to='episodeofcare.episodeofcarestatushistory'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('encounters', '0001_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0001_initial'),
        ('patients', '0002_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='encounter',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_patient', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='subject_status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_subject_status', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='encounter_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='virtual_service',
            field=models.ManyToManyField(blank=True, related_name='encounter_virtual_service', to='base.virtualservicedetails'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='admit_source',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_admit_source', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='destination',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='admission_destination', to='locations.locationorganizationreference'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='discharge_disposition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_discharge_disposition', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='origin',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='admission_origin', to='locations.locationorganizationreference'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='pre_admission_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_pre_admission_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='encounteradmission',
            name='re_admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission_re_admission', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='encounter',
            name='admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_admission', to='encounters.encounteradmission'),
        ),
        migrations.AddField(
            model_name='encounterbasedonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_based_on_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='encounterbasedonreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_based_on_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('genomicstudy', '0001_initial'),
        ('observations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='regions_called',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_regions_called', to='observations.documentreferenceobservationreference'),
        ),
        migrations.AddField(
            model_name='genomicstudyanalysis',
            name='regions_studied',
            field=models.ManyToManyField(blank=True, related_name='genomic_study_analysis_regions_studied', to='observations.documentreferenceobservationreference'),
        ),
    ]



"""provinces models."""

from django.db import models

from dfhir.base.models import BaseReference, Identifier, Reference, TimeStampedModel

# Create your models here.


class Provenance(TimeStampedModel):
    """Provinance model."""

    target = models.ManyToManyField(
        Reference, related_name="provinance_target", blank=True
    )
    # TODO: setting up a minimal implementation of provenance model. It will be implemented full in a difference ticket.


class ProvenanceReference(BaseReference):
    """medication request insurance reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.SET_NULL,
        null=True,
        related_name="provinance_reference_identifier",
    )
    provenance = models.ForeignKey(
        Provenance,
        on_delete=models.SET_NULL,
        null=True,
        related_name="provinance_reference_provenance",
    )



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0003_initial'),
        ('devices', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='appointmentresponseactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_actor_reference_device', to='devices.device'),
        ),
    ]



"""inventory reports app."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class InventoryreportsConfig(AppConfig):
    """Inventory reports config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.inventoryreports"
    verbose_name = _("Inventory Reports")



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('bodystructures', '0002_initial'),
        ('claims', '0004_initial'),
        ('conditions', '0003_initial'),
        ('coverages', '0002_initial'),
        ('devices', '0001_initial'),
        ('encounters', '0003_initial'),
        ('explanationofbenefits', '0003_initial'),
        ('locations', '0001_initial'),
        ('medicationrequests', '0002_initial'),
        ('nutritionorders', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('procedures', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='explanationofbenefit',
            name='referral',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_referral', to='servicerequests.servicerequestreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='sub_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_sub_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitaccident',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_accident_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitaccident',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_accident_location_location', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitaccident',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_accident_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='accident',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_accident', to='explanationofbenefits.explanationofbenefitaccident'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='add_item',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_add_item', to='explanationofbenefits.explanationofbenefitadditem'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail', to='explanationofbenefits.explanationofbenefitadditemdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail', to='explanationofbenefits.explanationofbenefitadditemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='network',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_network', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_term', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_unit', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='benefit_balance',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_benefit_balance', to='explanationofbenefits.explanationofbenefitbenefitbalance'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalancefinancial',
            name='allowed_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_financial_allowed_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalancefinancial',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_financial_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalancefinancial',
            name='used_money',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_benefit_balance_financial_used_money', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitbenefitbalance',
            name='financial',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_benefit_balance_financial', to='explanationofbenefits.explanationofbenefitbenefitbalancefinancial'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitcareteam',
            name='role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_care_team_role', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitcareteam',
            name='specialty',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_care_team_qualification', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_care_team', to='explanationofbenefits.explanationofbenefitcareteam'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='diagnosis_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_diagnosis_diagnosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='diagnosis_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_diagnosis_diagnosis_reference', to='conditions.conditionreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='on_admission',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_diagnosis_on_admission', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitdiagnosis',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_diagnosis_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='diagnosis',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_diagnosis', to='explanationofbenefits.explanationofbenefitdiagnosis'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitentererreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_enterer_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='enterer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_enterer', to='explanationofbenefits.explanationofbenefitentererreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitevent',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_event_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitevent',
            name='when_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_event_when_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='event',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_event', to='explanationofbenefits.explanationofbenefitevent'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitinsurance',
            name='coverage',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_insurance_coverage', to='coverages.coveragereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='insurance',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_insurance', to='explanationofbenefits.explanationofbenefitinsurance'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='encounter',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='location_address',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_location_address', to='base.address'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='location_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_location_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='location_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_location_reference', to='locations.locationreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='serviced_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_serviced_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='item',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_item', to='explanationofbenefits.explanationofbenefititem'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemadjudication',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_adjudication_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_sub_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititembodysite',
            name='site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_body_site_site', to='bodystructures.bodystructurecodeablereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititembodysite',
            name='sub_site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_body_site_sub_site', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_body_site', to='explanationofbenefits.explanationofbenefititembodysite'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='body_site',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_body_site', to='explanationofbenefits.explanationofbenefititembodysite'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail', to='explanationofbenefits.explanationofbenefititemdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='adjudication',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_adjudication', to='explanationofbenefits.explanationofbenefititemadjudication'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='modifier',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_modifier', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='net',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_net', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='patient_paid',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_patient_paid', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='product_or_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_product_or_service', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='product_or_service_end',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_product_or_service_end', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='program_code',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_program_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_quantity', to='base.simplequantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='revenue',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_revenue', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='tax',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_tax', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='trace_number',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_trace_number', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='unit_price',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_unit_price', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='sub_detail',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_detail_sub_detail', to='explanationofbenefits.explanationofbenefititemdetailsubdetail'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemrequestreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_request_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_request', to='explanationofbenefits.explanationofbenefititemrequestreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='request',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_request', to='explanationofbenefits.explanationofbenefititemrequestreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemreviewoutcome',
            name='decision',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_review_outcome_decision', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemreviewoutcome',
            name='pre_auth_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_review_outcome_pre_auth_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemreviewoutcome',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_item_review_outcome_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetailsubdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_sub_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititemdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefititem',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_item_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetailsubdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_sub_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditemdetail',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_detail_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='review_outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_add_item_review_outcome', to='explanationofbenefits.explanationofbenefititemreviewoutcome'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayee',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='payee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_payee', to='explanationofbenefits.explanationofbenefitpayee'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayeepartyreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayee',
            name='party',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payee_party', to='explanationofbenefits.explanationofbenefitpayeepartyreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='adjustment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_adjustment', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='adjustment_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_adjustment_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitpayment',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_payment_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='payment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_payment', to='explanationofbenefits.explanationofbenefitpayment'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprescriptionreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_prescription_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprescriptionreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_prescription_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprescriptionreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_prescription_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_prescription', to='explanationofbenefits.explanationofbenefitprescriptionreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='procedure_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_procedure_procedure_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='procedure_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_procedure_procedure_reference', to='procedures.procedurereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='type',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_procedure_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocedure',
            name='udi',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_procedure_udi', to='devices.devicereference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_procedure', to='explanationofbenefits.explanationofbenefitprocedure'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocessnote',
            name='language',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_process_note_language', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitprocessnote',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_process_note_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='process_note',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_process_note', to='explanationofbenefits.explanationofbenefitprocessnote'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_provider_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitcareteam',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_care_team_provider', to='explanationofbenefits.explanationofbenefitproviderreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitadditem',
            name='provider',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefit_add_item_provider', to='explanationofbenefits.explanationofbenefitproviderreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_provider', to='explanationofbenefits.explanationofbenefitproviderreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitrelated',
            name='claim',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_related_claim', to='claims.claimreference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitrelated',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_related_reference', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitrelated',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_related_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='related',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_funds_related', to='explanationofbenefits.explanationofbenefitrelated'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_reason', to='base.coding'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='timing_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_timing_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_quantity', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='explanationofbenefitsupportinginfo',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_supporting_info_value_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='supporting_info',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_supporting_info', to='explanationofbenefits.explanationofbenefitsupportinginfo'),
        ),
        migrations.AddField(
            model_name='explanationofbenefittotal',
            name='amount',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_total_amount', to='base.money'),
        ),
        migrations.AddField(
            model_name='explanationofbenefittotal',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefit_total_category', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='explanationofbenefit',
            name='total',
            field=models.ManyToManyField(blank=True, related_name='explanation_of_benefits_total', to='explanationofbenefits.explanationofbenefittotal'),
        ),
    ]



"""provenance serializers."""

from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    IdentifierSerializer,
)
from dfhir.provenances.models import Provenance, ProvenanceReference


class ProvenanceReferenceSerializer(BaseReferenceModelSerializer):
    """Provenance reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ProvenanceReference
        exclude = ["created_at", "updated_at"]


class ProvenanceSerializer(BaseWritableNestedModelSerializer):
    """Provenance serializer."""

    target = ProvenanceReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = Provenance
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('enrollmentrequests', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='enrollmentrequest',
            name='candidate',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_candidate', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='enrollmentrequest',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='enrollment_request_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='enrollmentrequest',
            name='insurer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_insurer', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='enrollmentrequest',
            name='provider',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_request_provider', to='enrollmentrequests.enrollmentrequestproviderreference'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestsreference',
            name='enrollment_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_requests_reference_enrollment_request', to='enrollmentrequests.enrollmentrequest'),
        ),
        migrations.AddField(
            model_name='enrollmentrequestsreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_requests_reference_identifier', to='base.identifier'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('appointmentresponses', '0005_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='appointmentresponseactorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='appointmentresponseactorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='appointmentresponseactorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_actor_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='appointmentresponseactorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='appointmentresponse',
            name='actor',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='appointment_response_actor', to='appointmentresponses.appointmentresponseactorreference'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careteams', '0002_initial'),
        ('devices', '0001_initial'),
        ('groups', '0001_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='groupmanagingentityreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_managing_entity_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='group',
            name='managing_entity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_managing_entity', to='groups.groupmanagingentityreference'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='involvement',
            field=models.ManyToManyField(blank=True, related_name='group_member_involvement', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='group',
            name='member',
            field=models.ManyToManyField(blank=True, related_name='group_member', to='groups.groupmember'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='groupmemberentityreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='groupmember',
            name='entity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_member_entity', to='groups.groupmemberentityreference'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='groupreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='group_reference_identifier', to='base.identifier'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='PersonLink',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('assurance', models.CharField(choices=[('level1', 'level1'), ('level2', 'level2'), ('level3', 'level3'), ('level4', 'level4')], max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('gender', models.CharField(choices=[('male', 'male'), ('female', 'female'), ('other', 'other'), ('unknown', 'unknown')], max_length=255, null=True)),
                ('birth_date', models.DateField(null=True)),
                ('deceased_boolean', models.BooleanField(null=True)),
                ('deceased_date_time', models.DateTimeField(null=True)),
                ('address', models.ManyToManyField(blank=True, related_name='persons_address', to='base.address')),
                ('communication', models.ManyToManyField(blank=True, related_name='persons_communication', to='base.communication')),
                ('identifier', models.ManyToManyField(blank=True, related_name='persons_identifier', to='base.identifier')),
                ('managing_organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='persons_managing_organization', to='base.organizationreference')),
                ('marital_status', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='persons_marital_status', to='base.codeableconcept')),
                ('name', models.ManyToManyField(blank=True, related_name='persons_name', to='base.humanname')),
                ('photo', models.ManyToManyField(blank=True, related_name='persons_photo', to='base.attachment')),
                ('telecom', models.ManyToManyField(blank=True, related_name='persons_telecom', to='base.contactpoint')),
                ('link', models.ManyToManyField(blank=True, related_name='persons_link', to='persons.personlink')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PersonLinkTargetReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_link_target_reference_identifier', to='base.identifier')),
                ('patient', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_link_target_reference_patient', to='patients.patient')),
                ('person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_link_target_reference_person', to='persons.person')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_link_target_reference_practitioner', to='practitioners.practitioner')),
                ('related_person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_link_target_reference_related_person', to='relatedpersons.relatedperson')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='personlink',
            name='target',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='person_link_target', to='persons.personlinktargetreference'),
        ),
        migrations.CreateModel(
            name='PersonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_reference_identifier', to='base.identifier')),
                ('person', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='person_reference_person', to='persons.person')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('patients', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='patientrelatedpersonreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='patient_related_person_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='patientlink',
            name='other',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='patient_link_other', to='patients.patientrelatedpersonreference'),
        ),
    ]



"""observation app configuration module."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ObservationsConfig(AppConfig):
    """Observations app configuration."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.observations"
    verbose_name = _("Observations")



"""imaging study URL Configuration."""

from django.urls import path

from dfhir.imagingstudy import views

app_name = "imagingstudy"

urlpatterns = [
    path("imagingstudy/", views.ImagingStudyListView.as_view(), name="list"),
    path(
        "imagingstudy/<int:pk>/", views.ImagingStudyDetailView.as_view(), name="detail"
    ),
]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('devices', '0001_initial'),
        ('medicationstatements', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationstatement',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_subject', to='patients.patientgroupreference'),
        ),
        migrations.AddField(
            model_name='medicationstatementadherence',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_adherence_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationstatementadherence',
            name='reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_adherence_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='adherence',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_adherence', to='medicationstatements.medicationstatementadherence'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='medicationstatementinformationsourcereference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_information_source_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='medicationstatement',
            name='information_source',
            field=models.ManyToManyField(blank=True, related_name='medication_statement_information_source', to='medicationstatements.medicationstatementinformationsourcereference'),
        ),
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='medicationstatementpartofreference',
            name='medication_statement',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='medication_statement_part_of_reference_medication_statement', to='medicationstatements.medicationstatement'),
        ),
    ]



"""image selection app."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ImagingselectionsConfig(AppConfig):
    """Image selections config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.imagingselections"
    verbose_name = _("Image Selections")



"""DeviceUsages views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import DeviceUsage
from .serializers import DeviceUsageSerializer


class DeviceUsageListView(APIView):
    """DeviceUsage list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: DeviceUsageSerializer(many=True)})
    def get(self, request):
        """Get a list of device usages."""
        device_usages = DeviceUsage.objects.all()
        serializer = DeviceUsageSerializer(device_usages, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=DeviceUsageSerializer, responses={201: DeviceUsageSerializer}
    )
    def post(self, request):
        """Create a device usage."""
        serializer = DeviceUsageSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class DeviceUsageDetailView(APIView):
    """DeviceUsage detail view."""

    permission_classes = [AllowAny]

    def get_object(self, pk):
        """Get a device usage object."""
        try:
            return DeviceUsage.objects.get(pk=pk)
        except DeviceUsage.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: DeviceUsageSerializer})
    def get(self, request, pk=None):
        """Get a device usage."""
        device_usage = self.get_object(pk)
        serializer = DeviceUsageSerializer(device_usage)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=DeviceUsageSerializer, responses={200: DeviceUsageSerializer}
    )
    def patch(self, request, pk=None):
        """Update a device usage."""
        device_usage = self.get_object(pk)
        serializer = DeviceUsageSerializer(
            device_usage, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk=None):
        """Delete a device usage."""
        device_usage = self.get_object(pk)
        device_usage.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""Explanation of Benefits serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer
from rest_framework import serializers

from dfhir.base.serializers import (
    AddressSerializer,
    AttachmentSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    CodingSerializer,
    IdentifierSerializer,
    MoneySerializer,
    OrganizationReferenceSerializer,
    PeriodSerializer,
    QuantitySerializer,
    ReferenceSerializer,
    SimpleQuantitySerializer,
)
from dfhir.bodystructures.serializers import BodyStructureCodeableReferenceSerializer
from dfhir.claims.serializers import ClaimReferenceSerializer
from dfhir.conditions.serializers import ConditionReferenceSerializer
from dfhir.coverages.serializers import CoverageReferenceSerializer
from dfhir.devices.serializers import DeviceReferenceSerializer
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.locations.serializers import (
    LocationOrganizationReferenceSerializer,
    LocationReferenceSerializer,
)
from dfhir.patients.serializers import PatientReferenceSerializer
from dfhir.procedures.serializers import ProcedureReferenceSerializer
from dfhir.servicerequests.serializers import ServiceRequestReferenceSerializer

from .models import (
    ExplanationOfBenefit,
    ExplanationOfBenefitAccident,
    ExplanationOfBenefitAddItem,
    ExplanationOfBenefitAddItemDetail,
    ExplanationOfBenefitBenefitBalance,
    ExplanationOfBenefitBenefitBalanceFinancial,
    ExplanationOfBenefitCareTeam,
    ExplanationOfBenefitDiagnosis,
    ExplanationOfBenefitEntererReference,
    ExplanationOfBenefitEvent,
    ExplanationOfBenefitInsurance,
    ExplanationOfBenefitItem,
    ExplanationOfBenefitItemAdjudication,
    ExplanationOfBenefitItemBodySite,
    ExplanationOfBenefitItemDetail,
    ExplanationOfBenefitItemDetailSubDetail,
    ExplanationOfBenefitItemRequestReference,
    ExplanationOfBenefitItemReviewOutcome,
    ExplanationOfBenefitPayee,
    ExplanationOfBenefitPayeePartyReference,
    ExplanationOfBenefitPayment,
    ExplanationOfBenefitPrescriptionReference,
    ExplanationOfBenefitProcedure,
    ExplanationOfBenefitProcessNote,
    ExplanationOfBenefitProviderReference,
    ExplanationOfBenefitRelated,
    ExplanationOfBenefitSupportingInfo,
    ExplanationOfBenefitTotal,
)


class ExplanationOfBenefitPrescriptionReferenceSerializer(BaseReferenceModelSerializer):
    """Explanation of Benefit Prescription Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitPrescriptionReference
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitProviderReferenceSerializer(BaseReferenceModelSerializer):
    """Explanation of Benefit Provider Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitProviderReference
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemRequestReferenceSerializer(BaseReferenceModelSerializer):
    """Explanation of Benefit Item Request Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItemRequestReference
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitsRelatedSerializer(WritableNestedModelSerializer):
    """Explanation of Benefits Related Serializer."""

    claim = ClaimReferenceSerializer(many=False, required=False)
    relationship = CodeableConceptSerializer(many=False, required=False)
    reference = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitRelated
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitBenefitBalanceFinancialSerializer(
    WritableNestedModelSerializer
):
    """Explanation of Benefit Benefit Balance Financial Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    allowed_money = MoneySerializer(many=False, required=False)
    used_money = MoneySerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitBenefitBalanceFinancial
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemBodySiteSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Item Body Site Serializer."""

    site = BodyStructureCodeableReferenceSerializer(many=True, required=False)
    sub_site = CodingSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItemBodySite
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemReviewOutcomeSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Item Review Outcome Serializer."""

    code = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItemReviewOutcome
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemAdjudicationSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Item Adjudication Serializer."""

    category = CodeableConceptSerializer(many=False, required=False)
    reason = CodeableConceptSerializer(many=False, required=False)
    amount = MoneySerializer(many=False, required=False)
    quantity = QuantitySerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItemAdjudication
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemDetailSubDetailSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Item Detail Sub Detail Serializer."""

    trace_number = IdentifierSerializer(many=True, required=False)
    revenue = CodeableConceptSerializer(many=False, required=False)
    category = CodeableConceptSerializer(many=False, required=False)
    product_or_service = CodeableConceptSerializer(many=False, required=False)
    product_or_service_end = CodeableConceptSerializer(many=False, required=False)
    modifier = CodeableConceptSerializer(many=True, required=False)
    program_code = CodeableConceptSerializer(many=True, required=False)
    patient_paid = MoneySerializer(many=False, required=False)
    quantity = SimpleQuantitySerializer(many=False, required=False)
    unit_price = MoneySerializer(many=False, required=False)
    tax = MoneySerializer(many=False, required=False)
    net = MoneySerializer(many=False, required=False)
    udi = DeviceReferenceSerializer(many=True, required=False)
    review_outcome = ExplanationOfBenefitItemReviewOutcomeSerializer(
        many=False, required=False
    )
    adjudication = ExplanationOfBenefitItemAdjudicationSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItemDetailSubDetail
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitAddItemDetailSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Add Item Detail Serializer."""

    trace_number = IdentifierSerializer(many=True, required=False)
    revenue = CodeableConceptSerializer(many=False, required=False)
    product_or_service = CodeableConceptSerializer(many=False, required=False)
    product_or_service_end = CodeableConceptSerializer(many=False, required=False)
    modifier = CodeableConceptSerializer(many=True, required=False)
    patient_paid = MoneySerializer(many=False, required=False)
    quantity = SimpleQuantitySerializer(many=False, required=False)
    unit_price = MoneySerializer(many=False, required=False)
    tax = MoneySerializer(many=False, required=False)
    net = MoneySerializer(many=False, required=False)
    review_outcome = ExplanationOfBenefitItemReviewOutcomeSerializer(
        many=False, required=False
    )
    adjudication = ExplanationOfBenefitItemAdjudicationSerializer(
        many=True, required=False
    )
    sub_detail = ExplanationOfBenefitItemDetailSubDetailSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitAddItemDetail
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitBenefitBalanceSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Benefit Balance Serializer."""

    category = CodeableConceptSerializer(many=False, required=False)
    network = CodeableConceptSerializer(many=False, required=False)
    unit = CodeableConceptSerializer(many=False, required=False)
    term = CodeableConceptSerializer(many=False, required=False)
    financial = ExplanationOfBenefitBenefitBalanceFinancialSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitBenefitBalance
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitPayeePartyReferenceSerializer(BaseReferenceModelSerializer):
    """Explanation of Benefit Payee Party Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitPayeePartyReference
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitPayeeSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Payee Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    party = ExplanationOfBenefitPayeePartyReferenceSerializer(
        many=False, required=False
    )

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitPayee
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitDiagnosisSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Diagnosis Serializer."""

    diagnosis_codeable_concept = CodeableConceptSerializer(many=False, required=False)
    diagnosis_reference = ConditionReferenceSerializer(many=False, required=False)
    type = CodeableConceptSerializer(many=True, required=False)
    on_admission = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitDiagnosis
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemDetailSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Item Detail Serializer."""

    trace_number = IdentifierSerializer(many=True, required=False)
    revenue = CodeableConceptSerializer(many=False, required=False)
    category = CodeableConceptSerializer(many=False, required=False)
    product_or_service = CodeableConceptSerializer(many=False, required=False)
    product_or_service_end = CodeableConceptSerializer(many=False, required=False)
    modifier = CodeableConceptSerializer(many=True, required=False)
    program_code = CodeableConceptSerializer(many=True, required=False)
    patient_paid = MoneySerializer(many=False, required=False)
    quantity = SimpleQuantitySerializer(many=False, required=False)
    unit_price = MoneySerializer(many=False, required=False)
    tax = MoneySerializer(many=False, required=False)
    net = MoneySerializer(many=False, required=False)
    udi = DeviceReferenceSerializer(many=True, required=False)
    review_outcome = ExplanationOfBenefitItemReviewOutcomeSerializer(
        many=False, required=False
    )
    adjudication = ExplanationOfBenefitItemAdjudicationSerializer(
        many=True, required=False
    )
    sub_detail = ExplanationOfBenefitItemDetailSubDetailSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItemDetail
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitItemSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Item Serializer."""

    trace_number = IdentifierSerializer(many=True, required=False)
    revenue = CodeableConceptSerializer(many=False, required=False)
    category = CodeableConceptSerializer(many=False, required=False)
    product_or_service = CodeableConceptSerializer(many=False, required=False)
    product_or_service_end = CodeableConceptSerializer(many=False, required=False)
    request = ExplanationOfBenefitItemRequestReferenceSerializer(
        many=True, required=False
    )
    modifier = CodeableConceptSerializer(many=True, required=False)
    program_code = CodeableConceptSerializer(many=True, required=False)
    serviced_period = PeriodSerializer(many=False, required=False)
    location_codeable_concept = CodeableConceptSerializer(many=False, required=False)
    location_address = AddressSerializer(many=False, required=False)
    location_reference = LocationReferenceSerializer(many=False, required=False)
    patient_paid = MoneySerializer(many=False, required=False)
    quantity = SimpleQuantitySerializer(many=False, required=False)
    unit_price = MoneySerializer(many=False, required=False)
    tax = MoneySerializer(many=False, required=False)
    net = MoneySerializer(many=False, required=False)
    udi = DeviceReferenceSerializer(many=True, required=False)
    body_site = ExplanationOfBenefitItemBodySiteSerializer(many=False, required=False)
    encounter = EncounterReferenceSerializer(many=True, required=False)
    review_outcome = ExplanationOfBenefitItemReviewOutcomeSerializer(
        many=False,
        required=False,
    )
    adjudication = ExplanationOfBenefitItemAdjudicationSerializer(
        many=True, required=False
    )
    detail = ExplanationOfBenefitItemDetailSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitItem
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitAccidentSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Accident Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    location_address = AddressSerializer(many=False, required=False)
    location_reference = LocationReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitAccident
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitInsuranceSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Insurance Serializer."""

    focal = serializers.BooleanField(required=False)
    coverage = CoverageReferenceSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitInsurance
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitEventSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Event Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    when_period = PeriodSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitEvent
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitPaymentSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Payment Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    adjustment = MoneySerializer(many=False, required=False)
    adjustment_reason = CodeableConceptSerializer(many=False, required=False)
    amount = MoneySerializer(many=False, required=False)
    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitPayment
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitProcedureSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Procedure Serializer."""

    type = CodeableConceptSerializer(many=True, required=False)
    procedure_codeable_concept = CodeableConceptSerializer(many=False, required=False)
    procedure_reference = ProcedureReferenceSerializer(many=False, required=False)
    udi = DeviceReferenceSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitProcedure
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitTotalSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Total Serializer."""

    category = CodeableConceptSerializer(many=False, required=False)
    amount = MoneySerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitTotal
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitAddItemSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Add Item Serializer."""

    trace_number = IdentifierSerializer(many=True, required=False)
    provider = ExplanationOfBenefitProviderReferenceSerializer(
        many=True, required=False
    )
    revenue = CodeableConceptSerializer(many=False, required=False)
    product_or_Service = CodeableConceptSerializer(many=False, required=False)
    product_or_service_end = CodeableConceptSerializer(many=False, required=False)
    request = ExplanationOfBenefitItemRequestReferenceSerializer(
        many=True, required=False
    )
    modifier = CodeableConceptSerializer(many=True, required=False)
    program_code = CodeableConceptSerializer(many=True, required=False)
    serviced_period = PeriodSerializer(many=False, required=False)
    location_codeable_concept = CodeableConceptSerializer(many=False, required=False)
    location_address = AddressSerializer(many=False, required=False)
    location_reference = LocationReferenceSerializer(many=False, required=False)
    patient_paid = MoneySerializer(many=False, required=False)
    quantity = SimpleQuantitySerializer(many=False, required=False)
    unit_price = MoneySerializer(many=False, required=False)
    tax = MoneySerializer(many=False, required=False)
    net = MoneySerializer(many=False, required=False)
    body_site = ExplanationOfBenefitItemBodySiteSerializer(many=False, required=False)
    review_outcome = ExplanationOfBenefitItemReviewOutcomeSerializer(
        many=False, required=False
    )
    adjudication = ExplanationOfBenefitItemAdjudicationSerializer(
        many=True, required=False
    )
    detail = ExplanationOfBenefitAddItemDetailSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitAddItem
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitCareTeamSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Care Team Serializer."""

    provider = ExplanationOfBenefitProviderReferenceSerializer(
        many=False, required=False
    )
    role = CodeableConceptSerializer(many=False, required=False)
    specialty = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitCareTeam
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitEntererReferenceSerializer(BaseReferenceModelSerializer):
    """Explanation of Benefit Enterer Reference Serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitEntererReference
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitProcessNoteSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Process Note Serializer."""

    type = CodeableConceptSerializer(many=False, required=False)
    language = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitProcessNote
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitSupportingInfoSerializer(WritableNestedModelSerializer):
    """Explanation of Benefit Supporting Info Serializer."""

    category = CodeableConceptSerializer(many=False, required=False)
    code = CodeableConceptSerializer(many=False, required=False)
    timing_period = PeriodSerializer(many=False, required=False)
    value_quantity = QuantitySerializer(many=False, required=False)
    value_attachment = AttachmentSerializer(many=False, required=False)
    value_reference = ReferenceSerializer(many=False, required=False)
    value_identifier = IdentifierSerializer(many=False, required=False)
    reason = CodingSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefitSupportingInfo
        exclude = ["created_at", "updated_at"]


class ExplanationOfBenefitSerializer(BaseWritableNestedModelSerializer):
    """Explanation of Benefits Serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    trace_number = IdentifierSerializer(many=True, required=False)
    type = CodeableConceptSerializer(many=False, required=False)
    sub_type = CodeableConceptSerializer(many=False, required=False)
    patient = PatientReferenceSerializer(many=False, required=False)
    billable_period = PeriodSerializer(many=False, required=False)
    enterer = ExplanationOfBenefitEntererReferenceSerializer(many=False, required=False)
    insurer = OrganizationReferenceSerializer(many=False, required=False)
    provider = ExplanationOfBenefitProviderReferenceSerializer(
        many=False, required=False
    )
    priority = CodeableConceptSerializer(many=False, required=False)
    funds_reserve_requested = CodeableConceptSerializer(many=False, required=False)
    funds_reserve = CodeableConceptSerializer(many=False, required=False)
    related = ExplanationOfBenefitsRelatedSerializer(many=True, required=False)
    prescription = ExplanationOfBenefitPrescriptionReferenceSerializer(
        many=False, required=False
    )
    original_prescription = ExplanationOfBenefitPrescriptionReferenceSerializer(
        many=False, required=False
    )
    event = ExplanationOfBenefitEventSerializer(many=True, required=False)
    payee = ExplanationOfBenefitPayeeSerializer(many=False, required=False)
    referral = ServiceRequestReferenceSerializer(many=False, required=False)
    facility = LocationOrganizationReferenceSerializer(many=False, required=False)
    claim = ClaimReferenceSerializer(many=False, required=False)
    decision = CodeableConceptSerializer(many=False, required=False)
    pre_auth_period = PeriodSerializer(many=False, required=False)
    diagnosis_related_group = CodeableConceptSerializer(many=False, required=False)
    care_team = ExplanationOfBenefitCareTeamSerializer(many=True, required=False)
    supporting_info = ExplanationOfBenefitSupportingInfoSerializer(
        many=True, required=False
    )
    diagnosis = ExplanationOfBenefitDiagnosisSerializer(many=True, required=False)
    procedure = ExplanationOfBenefitProcedureSerializer(many=True, required=False)
    insurance = ExplanationOfBenefitInsuranceSerializer(many=True, required=False)
    accident = ExplanationOfBenefitAccidentSerializer(many=False, required=False)
    patient_paid = MoneySerializer(many=False, required=False)
    item = ExplanationOfBenefitItemSerializer(many=True, required=False)
    add_item = ExplanationOfBenefitAddItemSerializer(many=True, required=False)
    adjudication = ExplanationOfBenefitItemAdjudicationSerializer(
        many=True, required=False
    )
    total = ExplanationOfBenefitTotalSerializer(many=True, required=False)
    payment = ExplanationOfBenefitPaymentSerializer(many=False, required=False)
    form_code = CodeableConceptSerializer(many=False, required=False)
    form = AttachmentSerializer(many=False, required=False)
    process_note = ExplanationOfBenefitProcessNoteSerializer(many=True, required=False)
    benefit_period = PeriodSerializer(many=False, required=False)
    benefit_balance = ExplanationOfBenefitBenefitBalanceSerializer(
        many=True, required=False
    )

    class Meta:
        """Meta class."""

        model = ExplanationOfBenefit
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('activitydefinitions', '0003_initial'),
        ('careteams', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_practitioner_type_reference_care_plan', to='careteams.careteam'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('enrollmentrequests', '0001_initial'),
        ('organizations', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='EnrollmentResponseRequestProviderReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_request_provider_reference_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_request_provider_reference_organization', to='organizations.organization')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_request_provider_reference_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_request_provider_reference_practitioner_role', to='practitioners.practitionerrole')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EnrollmentResponse',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_created=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('active', 'Active'), ('cancelled', 'Cancelled'), ('draft', 'Draft'), ('entered-in-error', 'Entered in Error')], max_length=50, null=True)),
                ('outcome', models.CharField(choices=[('queued', 'Queued'), ('complete', 'Complete'), ('error', 'Error'), ('partial', 'Partial')], max_length=50, null=True)),
                ('disposition', models.TextField(null=True)),
                ('identifier', models.ManyToManyField(blank=True, related_name='enrollment_response_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_organization', to='base.organizationreference')),
                ('request', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_request', to='enrollmentrequests.enrollmentrequest')),
                ('request_provider', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='enrollment_response_request_provider', to='enrollmentresponses.enrollmentresponserequestproviderreference')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('careteams', '0002_initial'),
        ('conditions', '0003_initial'),
        ('devices', '0001_initial'),
        ('diagnosticreports', '0002_initial'),
        ('familymemberhistories', '0001_initial'),
        ('observations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='familymemberhistory',
            name='patient',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_patient', to='patients.patientreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='relationship',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_relationship', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='sex',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_sex', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_condition_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='onset_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_onset_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='familymemberhistorycondition',
            name='outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_condition_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='condition',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_condition', to='familymemberhistories.familymemberhistorycondition'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipant',
            name='function',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_function', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='participant',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_participant', to='familymemberhistories.familymemberhistoryparticipant'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipantactorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryparticipant',
            name='actor',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_participant_actor', to='familymemberhistories.familymemberhistoryparticipantactorreference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_procedure_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='outcome',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_outcome', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_age', to='base.age'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryprocedure',
            name='performed_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_procedure_performed_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='procedure',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_procedure', to='familymemberhistories.familymemberhistoryprocedure'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasoncodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_codeable_reference_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='familymemberhistory',
            name='reason',
            field=models.ManyToManyField(blank=True, related_name='family_member_history_reason', to='familymemberhistories.familymemberhistoryreasoncodeablereference'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='condition',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_condition', to='conditions.condition'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='diagnostic_report',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_diagnostic_report', to='diagnosticreports.diagnosticreport'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasonreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='familymemberhistoryreasoncodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_reason_codeable_reference_reference', to='familymemberhistories.familymemberhistoryreasonreference'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('bodystructures', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='DeviceAssociationOperation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DeviceAssociationOperationOperatorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DeviceAssociationSubjectReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DeviceAssociation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('body_structure', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='device_association_body_structure', to='bodystructures.bodystructurereference')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('flags', '0001_initial'),
        ('groups', '0002_initial'),
        ('locations', '0001_initial'),
        ('medications', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='flagauthorreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='flagauthorreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='flagauthorreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
        migrations.AddField(
            model_name='flagauthorreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='flag',
            name='author',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_author', to='flags.flagauthorreference'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='flagsubjectreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flag_subject_reference_practitioner_role', to='practitioners.practitionerrole'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('clinicalimpressions', '0001_initial'),
        ('conditions', '0001_initial'),
        ('encounters', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='clinicalimpression',
            name='encounter',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_encounter', to='encounters.encounterreference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='note',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_note', to='base.annotation'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='performer',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_performer', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='problem',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_problem', to='conditions.conditionallergyintolerancereference'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='prognosis_codeable_concept',
            field=models.ManyToManyField(blank=True, related_name='clinical_impression_prognosis_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='clinicalimpression',
            name='status_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='clinical_impression_status_reason', to='base.codeableconcept'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FormularyItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('active', 'Active'), ('entered-in-error', 'Entered in Error'), ('inactive', 'Inactive')], max_length=200, null=True)),
                ('code', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='formulary_item_code', to='base.codeableconcept')),
                ('identifier', models.ManyToManyField(blank=True, related_name='formulary_item_identifier', to='base.identifier')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FormularyItemReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('formulary_item', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='formulary_item_reference_formulary_item', to='formularyitems.formularyitem')),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='formulary_item_reference_identifier', to='base.identifier')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('explanationofbenefits', '0001_initial'),
        ('medicationrequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='explanationofbenefit',
            name='original_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='explanation_of_benefits_original_prescription', to='medicationrequests.medicationrequestreference'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-10 13:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BodyStructureCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BodyStructureReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DistanceFromLandmark',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='IncludedStructure',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BodyLandmarkOrientation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('clock_face_position', models.ManyToManyField(blank=True, related_name='body_landmark_orientation_clock_face_position', to='base.codeableconcept')),
                ('landmark_description', models.ManyToManyField(blank=True, related_name='body_landmark_orientation_landmark_description', to='base.codeableconcept')),
                ('surface_orientation', models.ManyToManyField(blank=True, related_name='body_landmark_orientation_surface_orientation', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='BodyStructure',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('description', models.TextField(null=True)),
                ('identifier', models.ManyToManyField(blank=True, related_query_name='body_structure_identifier', to='base.identifier')),
                ('image', models.ManyToManyField(blank=True, related_name='body_structure_image', to='base.attachment')),
                ('morphology', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='body_structure_morphology', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
